renewLock abstract method
Renews a lock on a message that makes it invisible from other receivers in the queue. This method is usually used to extend the message processing time.
messagea message to extend its lock.lockTimeouta locking timeout in milliseconds. Return Future that receives an null for success. Throws error
Implementation
Future renewLock(MessageEnvelope message, int lockTimeout);